Residual degrees-of-freedom is the trace of the residual hat matrix
Usage
# S3 method for class 'fastlmm'
df.residual(object, ...)Residual degrees-of-freedom is the trace of the residual hat matrix
# S3 method for class 'fastlmm'
df.residual(object, ...)