Skip to contents

Effective degrees-of-freedom of model fit is the trace of the hat matrix mapping from observed to predicted response

Usage

edf(object, ...)

Arguments

object

fitted model

...

other args, not used

Examples

library(MASS)

# GLMM via PQL
fit <- fastglmm(y ~ trt + I(week > 2) + (1 | ID),
   family = binomial(), data = bacteria)

edf(fit)
#> [1] 30.82029