Specifies the information required to fit a Negative Binomial generalized linear model, with known theta parameter.
Usage
negative.binomial(theta = stop("'theta' must be specified"), link = "log")Arguments
- theta
The known value of the additional parameter,
theta. If set toNA,fastglmm()will estimate the parameter from the data- link
The link function, as a character string, name or one-element character vector specifying one of
log,sqrtoridentity, or an object of class"link-glm".