Model Predictions
Arguments
- object
fitted model of class
fastlmm- newdata
optionally, a data frame in which to look for variables with which to predict. If omitted, the fitted predictors are used.
- type
the type of prediction required. The default is on the scale of the linear predictors; the alternative
"response"is on the scale of the response variable. Thus for a default binomial model the default predictions are of log-odds (probabilities on logit scale) andtype = "response"gives the predicted probabilities.type = "terms"computes the linear predict for each model term- ...
other args, not used